#version 150

in vec3 vertexPosition;
in vec4 vertexColor;
in vec3 vertexNormal;
in vec2 vertexTextureCoord;

uniform vec3 lightPos0, lightPos1;
uniform vec4 drawColor;
uniform mat3 normalMatrix;
uniform mat4 modelViewMatrix, projectionMatrix;
uniform sampler2D textureID;
uniform float scale;
uniform vec2 posOffset,size;

out vec2 textureCoord;
out vec3 lightDir0, normal;
out vec4 modelViewPos, color;

void main(void)
{
	// Store world position
	modelViewPos = modelViewMatrix * vec4(vertexPosition, 1.0);
	
	// Store normal
	normal = normalize(normalMatrix * vec3(0.0, 0.0, 1.0));
	
	// Store light direction
	lightDir0 = normalize((lightPos0 - modelViewPos.xyz));
	
	// Store texCoord
	textureCoord = (modelViewPos.xy + size/2.0 - posOffset) / (scale * 512.0);
	
	// Store screen position
	gl_Position = projectionMatrix * modelViewPos;
}